class DBUtilsSecrets:

    def get(self, *args):
        print("calling DBUtilsSecrets.get func from dummy dbutils package, and no operation performed.")

class DBUtilsWidgets:

    def removeAll(self):
        print("calling DBUtilsWidgets.removeAll func from dummy dbutils package, and no operation performed.")

    def text(self, *args):
        print("calling DBUtilsWidgets.text func from dummy dbutils package, and no operation performed.")

    def get(self, *args):
        print("calling DBUtilsWidgets.get func from dummy dbutils package, and no operation performed.")


class DButilsFunctions:

    def ls(self, dir: str):
        print("calling DButilsFunctions.ls func from dummy dbutils package, and no operation performed.")

    def mkdirs(self, dir: str):
        print("calling DButilsFunctions.mkdirs func from dummy dbutils package, and no operation performed.")

    def mv(self, src: str, tgt: str):
        print("calling DButilsFunctions.mv func from dummy dbutils package, and no operation performed.")

class DBUtils:

    def __init__(self):
        self.fs = DButilsFunctions()
        self.widgets = DBUtilsWidgets()
        self.secrets = DBUtilsSecrets()

dbutils = DBUtils()

# dbutils.fs.ls("dir")
# dbutils.fs.mkdirs("dir")
# dbutils.fs.mv("src", "tgt")




from setuptools import setup, find_packages
import os

VERSION = '0.0.3'
DESCRIPTION = 'Dummy Scripts for Databricks dbutils'
LONG_DESCRIPTION = 'A package that allows to use databricks dbutils without actual functionality. This helps to generate the build.'

# Setting up
setup(
    name="dummy_dbutils",
    version=VERSION,
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    long_description=LONG_DESCRIPTION,
    packages=find_packages(),

    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)